@@ -22,20 +22,26 @@ Create Date: 2015-04-17 14:20:17.620995
 revision = '592131657ca1'
 down_revision = '4956f03cabad'
 
-from alembic import op
+from alembic import op  # noqa: E402
 
-import magnum.conf
-import sqlalchemy as sa
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import magnum.conf  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 CONF = magnum.conf.CONF
 
 
 def upgrade():
-    op.add_column('baymodel', sa.Column('coe', sa.String(length=255),
+    op.add_column('baymodel', sa.Column('coe', String(255,
+                                        mysql_ndb_type=TINYTEXT),
                                         nullable=True))
 
     baymodel = sa.sql.table('baymodel',
-                            sa.sql.column('coe', sa.String(length=255)))
+                            sa.sql.column('coe', String(255,
+                                          mysql_ndb_type=TINYTEXT)))
 
     op.execute(
         baymodel.update().values({
