@@ -21,14 +21,22 @@ Create Date: 2015-08-24 11:23:24.262921
 revision = '966a99e70ff'
 down_revision = '6f21dc998bb'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
     op.add_column('baymodel', sa.Column('http_proxy',
-                                        sa.String(length=255), nullable=True))
+                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        nullable=True))
     op.add_column('baymodel', sa.Column('https_proxy',
-                                        sa.String(length=255), nullable=True))
+                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        nullable=True))
     op.add_column('baymodel', sa.Column('no_proxy',
-                                        sa.String(length=255), nullable=True))
+                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        nullable=True))
