@@ -12,13 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from magnum.drivers.common import k8s_monitor
-from magnum.drivers.common.k8s_scale_manager import K8sScaleManager
 from magnum.drivers.heat import driver
 from magnum.drivers.k8s_coreos_v1 import template_def
 
 
-class Driver(driver.HeatDriver):
+class Driver(driver.KubernetesDriver):
 
     @property
     def provides(self):
@@ -30,9 +28,3 @@ class Driver(driver.HeatDriver):
 
     def get_template_definition(self):
         return template_def.CoreOSK8sTemplateDefinition()
-
-    def get_monitor(self, context, cluster):
-        return k8s_monitor.K8sMonitor(context, cluster)
-
-    def get_scale_manager(self, context, osclient, cluster):
-        return K8sScaleManager(context, osclient, cluster)
