@@ -369,8 +369,9 @@ extendedKeyUsage = clientAuth
         return nodes
 
     def _get_nodes_from_stack(self):
+        cluster = self.cs.clusters.get(self.cluster.uuid)
         nodes = []
-        stack = self.heat.stacks.get(self.cluster.stack_id)
+        stack = self.heat.stacks.get(cluster.stack_id)
         stack_outputs = stack.to_dict().get('outputs', [])
         output_keys = []
         if self.cluster_template.coe == "kubernetes":
@@ -516,7 +517,7 @@ class BaseK8sTest(ClusterTest):
         self.assertEqual('frontend', resp.metadata.name)
         self.assertTrue(resp.status)
 
-        resp = self.k8s_api.delete_namespaced_service(name='frontend',
+        resp = self.k8s_api.delete_namespaced_service(name='frontend', body={},
                                                       namespace='default')
 
     def test_replication_controller_apis(self):
