@@ -11,8 +11,8 @@
 #    limitations under the License.
 
 import datetime
+from unittest import mock
 
-import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 from six.moves.urllib import parse as urlparse
@@ -158,9 +158,10 @@ class TestListBayModel(api_base.FunctionalTest):
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
         self.assertIn(uuid, response['links'][0]['href'])
-        for l in response['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'], bookmark=bookmark))
+        for link in response['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'],
+                                               bookmark=bookmark))
 
     def test_collection_links(self):
         for id_ in range(5):
@@ -640,7 +641,7 @@ class TestPost(api_base.FunctionalTest):
         mock_image_data.return_value = {'name': 'mock_name',
                                         'os_distro': 'fedora-atomic'}
         for k, v in baymodel_config_dict.items():
-                    CONF.set_override(k, v, 'cluster_template')
+            CONF.set_override(k, v, 'cluster_template')
         with mock.patch.object(
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
