@@ -11,8 +11,8 @@
 #    limitations under the License.
 
 import datetime
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
@@ -64,7 +64,8 @@ class TestListClusterTemplate(api_base.FunctionalTest):
                                'image_id', 'registry_enabled', 'no_proxy',
                                'keypair_id', 'https_proxy', 'tls_disabled',
                                'public', 'labels', 'master_flavor_id',
-                               'volume_driver', 'insecure_registry', 'hidden')
+                               'volume_driver', 'insecure_registry', 'hidden',
+                               'tags',)
 
     def test_empty(self):
         response = self.get_json('/clustertemplates')
@@ -217,9 +218,9 @@ class TestListClusterTemplate(api_base.FunctionalTest):
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
         self.assertIn(uuid, response['links'][0]['href'])
-        for l in response['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'],
+        for link in response['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'],
                                                bookmark=bookmark))
 
     def test_collection_links(self):
@@ -390,6 +391,18 @@ class TestPatch(api_base.FunctionalTest):
                                  self.cluster_template.uuid)
         self.assertEqual(response['hidden'], True)
 
+    def test_update_cluster_template_with_devicemapper(self):
+        cluster_template = obj_utils.create_test_cluster_template(self.context)
+        note = 'deprecated in favor of overlay2'
+        with self.assertWarnsRegex(DeprecationWarning, note):
+            response = self.patch_json('/clustertemplates/%s' %
+                                       cluster_template.uuid,
+                                       [{'path': '/docker_storage_driver',
+                                         'value': 'devicemapper',
+                                         'op': 'replace'}],
+                                       expect_errors=True)
+        self.assertEqual(200, response.status_int)
+
     def test_update_cluster_template_replace_labels_success(self):
         cluster_template = obj_utils.create_test_cluster_template(self.context)
         response = self.patch_json('/clustertemplates/%s' %
@@ -597,6 +610,20 @@ class TestPatch(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['errors'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_update_cluster_template_as_admin(self, mock_context, mock_policy):
+        temp_uuid = uuidutils.generate_uuid()
+        obj_utils.create_test_cluster_template(self.context, uuid=temp_uuid,
+                                               project_id=temp_uuid)
+        self.context.is_admin = True
+        response = self.patch_json('/clustertemplates/%s' % temp_uuid,
+                                   [{'path': '/name',
+                                     'value': 'cluster_model_example_B',
+                                     'op': 'replace'}],
+                                   expect_errors=True)
+        self.assertEqual(200, response.status_int)
+
 
 class TestPost(api_base.FunctionalTest):
 
@@ -759,7 +786,9 @@ class TestPost(api_base.FunctionalTest):
                                             'os_distro': 'fedora-atomic'}
             bdict = apiutils.cluster_template_post_data(
                 docker_volume_size=1, docker_storage_driver="overlay")
-            response = self.post_json('/clustertemplates', bdict)
+            note = 'deprecated in favor of overlay2'
+            with self.assertWarnsRegex(DeprecationWarning, note):
+                response = self.post_json('/clustertemplates', bdict)
             self.assertEqual(bdict['docker_volume_size'],
                              response.json['docker_volume_size'])
             cc_mock.assert_called_once_with(mock.ANY)
@@ -775,7 +804,7 @@ class TestPost(api_base.FunctionalTest):
         mock_image_data.return_value = {'name': 'mock_name',
                                         'os_distro': 'fedora-atomic'}
         for k, v in cluster_template_config_dict.items():
-                    cfg.CONF.set_override(k, v, 'cluster_template')
+            cfg.CONF.set_override(k, v, 'cluster_template')
         with mock.patch.object(
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
@@ -1115,6 +1144,30 @@ class TestPost(api_base.FunctionalTest):
         self.assertRaises(AppError, self.post_json, '/clustertemplates',
                           bdict)
 
+    @mock.patch('magnum.api.attr_validator.validate_image')
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_create_cluster_template_with_multi_dns(self, mock_utcnow,
+                                                    mock_image_data):
+        bdict = apiutils.cluster_template_post_data(
+            dns_nameserver="8.8.8.8,114.114.114.114")
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+        mock_image_data.return_value = {'name': 'mock_name',
+                                        'os_distro': 'fedora-atomic'}
+
+        response = self.post_json('/clustertemplates', bdict)
+        self.assertEqual(201, response.status_int)
+        # Check location header
+        self.assertIsNotNone(response.location)
+        expected_location = '/v1/clustertemplates/%s' % bdict['uuid']
+        self.assertEqual(expected_location,
+                         urlparse.urlparse(response.location).path)
+        self.assertEqual(bdict['uuid'], response.json['uuid'])
+        self.assertNotIn('updated_at', response.json.keys)
+        return_created_at = timeutils.parse_isotime(
+            response.json['created_at']).replace(tzinfo=None)
+        self.assertEqual(test_time, return_created_at)
+
 
 class TestDelete(api_base.FunctionalTest):
 
